@@ -3,11 +3,14 @@ from pandas.core.frame import DataFrame
 from typing import List, Union
 from tim.core.credentials import Credentials
 from tim.core.api import execute_request
-from tim.types import Logs, Status, StatusResponse, SortDirection
-from .types import CSVSeparator, DatasetListPayload, Dataset, DatasetListVersion, DatasetVersionListPayload, UploadCsvResponse, UploadCSVConfiguration
+from tim.types import Logs, Status, StatusResponse
+from .types import CSVSeparator, DatasetListPayload, Dataset, DatasetListVersion, UploadCsvResponse, UploadCSVConfiguration
 
 
 def __is_valid_csv_configuration(configuration: UploadCSVConfiguration) -> bool:
+  if configuration is None: 
+    return True
+
   if "csvSeparator" in configuration:
     return False
 
@@ -74,26 +77,23 @@ def get_dataset_logs(credentials: Credentials, id: str) -> List[Logs]:
 
 def get_datasets(
     credentials: Credentials,
-    offset: Union[int, None] = None,
-    limit: Union[int, None] = None,
+    offset: int,
+    limit: int,
     workspaceId: Union[str, None] = None,
-    sort: Union[SortDirection, None] = None
+    sort: Union[str, None] = None
 ) -> List[Dataset]:
 
-  payload = DatasetListPayload()
-  if offset: payload['offset'] = offset
-  if limit: payload['limit'] = limit
+  payload = DatasetListPayload(offset=offset, limit=limit)
   if workspaceId: payload['workspaceId'] = workspaceId
   if sort: payload['sort'] = sort
 
-  return execute_request(credentials=credentials, method='get', path='/datasets', body=payload)
+  return execute_request(
+      credentials=credentials, method='get', path=f'/datasets', params=payload
+  )
 
 
-def get_dataset_versions(
-    credentials: Credentials, id: str, offset: Union[int, None] = None, limit: Union[int, None] = None
-) -> List[DatasetListVersion]:
-  payload = DatasetVersionListPayload()
-  if offset: payload['offset'] = offset
-  if limit: payload['limit'] = limit
-
-  return execute_request(credentials=credentials, method='get', path=f'/datasets/{id}/versions', body=payload)
+def get_dataset_versions(credentials: Credentials, id: str, offset: int,
+                         limit: int) -> List[DatasetListVersion]:
+  return execute_request(
+      credentials=credentials, method='get', path=f'/datasets/{id}/versions?offset={offset}&limit={limit}'
+  )
